@@ -36,8 +36,6 @@
 #include "gstavutils.h"
 #include "gstavauddec.h"
 
-GST_DEBUG_CATEGORY_EXTERN (GST_CAT_PERFORMANCE);
-
 /* A number of function prototypes are given so we can refer to them later. */
 static void gst_ffmpegauddec_base_init (GstFFMpegAudDecClass * klass);
 static void gst_ffmpegauddec_class_init (GstFFMpegAudDecClass * klass);
@@ -704,7 +702,7 @@ gst_ffmpegauddec_handle_frame (GstAudioDecoder * decoder, GstBuffer * inbuf)
   GstMapInfo map;
   gint size, bsize, len, have_data;
   GstFlowReturn ret = GST_FLOW_OK;
-  gboolean do_padding;
+  gboolean do_padding, is_header;
 
   ffmpegdec = (GstFFMpegAudDec *) decoder;
 
@@ -717,6 +715,7 @@ gst_ffmpegauddec_handle_frame (GstAudioDecoder * decoder, GstBuffer * inbuf)
   }
 
   inbuf = gst_buffer_ref (inbuf);
+  is_header = GST_BUFFER_FLAG_IS_SET (inbuf, GST_BUFFER_FLAG_HEADER);
 
   oclass = (GstFFMpegAudDecClass *) (G_OBJECT_GET_CLASS (ffmpegdec));
 
@@ -750,7 +749,7 @@ gst_ffmpegauddec_handle_frame (GstAudioDecoder * decoder, GstBuffer * inbuf)
       GST_LOG_OBJECT (ffmpegdec, "resized padding buffer to %d",
           ffmpegdec->padded_size);
     }
-    GST_CAT_TRACE_OBJECT (GST_CAT_PERFORMANCE, ffmpegdec,
+    GST_CAT_TRACE_OBJECT (CAT_PERFORMANCE, ffmpegdec,
         "Copy input to add padding");
     memcpy (ffmpegdec->padded, bdata, bsize);
     memset (ffmpegdec->padded + bsize, 0, FF_INPUT_BUFFER_PADDING_SIZE);
@@ -769,7 +768,7 @@ gst_ffmpegauddec_handle_frame (GstAudioDecoder * decoder, GstBuffer * inbuf)
 
     if (do_padding) {
       /* add temporary padding */
-      GST_CAT_TRACE_OBJECT (GST_CAT_PERFORMANCE, ffmpegdec,
+      GST_CAT_TRACE_OBJECT (CAT_PERFORMANCE, ffmpegdec,
           "Add temporary input padding");
       memcpy (tmp_padding, data + size, FF_INPUT_BUFFER_PADDING_SIZE);
       memset (data + size, 0, FF_INPUT_BUFFER_PADDING_SIZE);
@@ -821,6 +820,9 @@ gst_ffmpegauddec_handle_frame (GstAudioDecoder * decoder, GstBuffer * inbuf)
     ret =
         gst_audio_decoder_finish_frame (GST_AUDIO_DECODER (ffmpegdec),
         ffmpegdec->outbuf, 1);
+  else if (len < 0 || is_header)
+    ret =
+        gst_audio_decoder_finish_frame (GST_AUDIO_DECODER (ffmpegdec), NULL, 1);
   ffmpegdec->outbuf = NULL;
 
   if (bsize > 0) {
@@ -864,7 +866,6 @@ gst_ffmpegauddec_register (GstPlugin * plugin)
 
   while (in_plugin) {
     gchar *type_name;
-    gchar *plugin_name;
 
     /* only decoders */
     if (!av_codec_is_decoder (in_plugin)
@@ -910,10 +911,8 @@ gst_ffmpegauddec_register (GstPlugin * plugin)
     }
 
     /* construct the type */
-    plugin_name = g_strdup ((gchar *) in_plugin->name);
-    g_strdelimit (plugin_name, NULL, '_');
-    type_name = g_strdup_printf ("avdec_%s", plugin_name);
-    g_free (plugin_name);
+    type_name = g_strdup_printf ("avdec_%s", in_plugin->name);
+    g_strdelimit (type_name, ".,|-<> ", '_');
 
     type = g_type_from_name (type_name);
 
